==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRouteBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageRegistryConfigRouteBuilder extends ImageRegistryConfigRouteFluentImpl<ImageRegistryConfigRouteBuilder> implements VisitableBuilder<ImageRegistryConfigRoute,ImageRegistryConfigRouteBuilder>{
  public ImageRegistryConfigRouteBuilder() {
    this(false);
  }
  public ImageRegistryConfigRouteBuilder(Boolean validationEnabled) {
    this(new ImageRegistryConfigRoute(), validationEnabled);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageRegistryConfigRoute(), validationEnabled);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent,ImageRegistryConfigRoute instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent,ImageRegistryConfigRoute instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHostname(instance.getHostname());
      fluent.withName(instance.getName());
      fluent.withSecretName(instance.getSecretName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRoute instance) {
    this(instance,false);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRoute instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withSecretName(instance.getSecretName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ImageRegistryConfigRouteFluent<?> fluent;
  Boolean validationEnabled;
  public ImageRegistryConfigRoute build() {
    ImageRegistryConfigRoute buildable = new ImageRegistryConfigRoute(fluent.getHostname(),fluent.getName(),fluent.getSecretName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRouteBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageRegistryConfigRouteBuilder extends ImageRegistryConfigRouteFluent<ImageRegistryConfigRouteBuilder> implements VisitableBuilder<ImageRegistryConfigRoute,ImageRegistryConfigRouteBuilder>{
  public ImageRegistryConfigRouteBuilder() {
    this(false);
  }
  public ImageRegistryConfigRouteBuilder(Boolean validationEnabled) {
    this(new ImageRegistryConfigRoute(), validationEnabled);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageRegistryConfigRoute(), validationEnabled);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent,ImageRegistryConfigRoute instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRouteFluent<?> fluent,ImageRegistryConfigRoute instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ImageRegistryConfigRoute());

    if (instance != null) {
      fluent.withHostname(instance.getHostname());
      fluent.withName(instance.getName());
      fluent.withSecretName(instance.getSecretName());
      fluent.withHostname(instance.getHostname());
      fluent.withName(instance.getName());
      fluent.withSecretName(instance.getSecretName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRoute instance) {
    this(instance,false);
  }
  public ImageRegistryConfigRouteBuilder(ImageRegistryConfigRoute instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ImageRegistryConfigRoute());

    if (instance != null) {
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withSecretName(instance.getSecretName());
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withSecretName(instance.getSecretName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ImageRegistryConfigRouteFluent<?> fluent;
  Boolean validationEnabled;
  public ImageRegistryConfigRoute build() {
    ImageRegistryConfigRoute buildable = new ImageRegistryConfigRoute(fluent.getHostname(),fluent.getName(),fluent.getSecretName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
